Changelog
=========


Version 0.8.3
-------------

:Date: July 13, 2022

Making the release properly and uploading it to PyPI.


Version 0.8.2
-------------

:Date: July 13, 2022

Mistake while releasing with bumpver.

Version 0.8.1
-------------

:Date: July 13, 2022

* Handle special case on Read the Docs URLs (https://github.com/readthedocs/sphinx-notfound-page/pull/200)

Version 0.8
-----------

:Date: October 11, 2021

* Update all Python dependencies via pyup bot
* Update test suite to run tests on Python 3.10, test on Sphinx 4 and pin docutils
* Fix issue with HTML logo/favicon on Sphinx 4.2.x


Version 0.7.1
-------------

:Date: May 20, 2021


Version 0.7
-----------

:Date: May 20, 2021


Version 0.6
-----------

:Date: January 04, 2021

* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx to 3.4.1 (`#122 <https://github.com/readthedocs/sphinx-notfound-page/pull/122>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx to 3.4.0 (`#121 <https://github.com/readthedocs/sphinx-notfound-page/pull/121>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx to 3.3.1 (`#119 <https://github.com/readthedocs/sphinx-notfound-page/pull/119>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx to 3.3.0 (`#118 <https://github.com/readthedocs/sphinx-notfound-page/pull/118>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinxemoji to 0.1.8 (`#116 <https://github.com/readthedocs/sphinx-notfound-page/pull/116>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinxemoji to 0.1.7 (`#115 <https://github.com/readthedocs/sphinx-notfound-page/pull/115>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx-autoapi to 1.5.1 (`#113 <https://github.com/readthedocs/sphinx-notfound-page/pull/113>`__)
* `@rscohn2 <https://github.com/rscohn2>`__: fix parallel read error and add test (`#112 <https://github.com/readthedocs/sphinx-notfound-page/pull/112>`__)
* `@sbraz <https://github.com/sbraz>`__: Include tests and docs in source distributions (`#110 <https://github.com/readthedocs/sphinx-notfound-page/pull/110>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx-prompt to 1.3.0 (`#109 <https://github.com/readthedocs/sphinx-notfound-page/pull/109>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx-tabs to 1.3.0 (`#108 <https://github.com/readthedocs/sphinx-notfound-page/pull/108>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx-autoapi to 1.5.0 (`#107 <https://github.com/readthedocs/sphinx-notfound-page/pull/107>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx-tabs to 1.2.1 (`#105 <https://github.com/readthedocs/sphinx-notfound-page/pull/105>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx-tabs to 1.2.0 (`#104 <https://github.com/readthedocs/sphinx-notfound-page/pull/104>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx to 3.2.1 (`#103 <https://github.com/readthedocs/sphinx-notfound-page/pull/103>`__)
* `@humitos <https://github.com/humitos>`__: Update Sphinx==3.1.2 (`#99 <https://github.com/readthedocs/sphinx-notfound-page/pull/99>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx-rtd-theme to 0.5.0 (`#98 <https://github.com/readthedocs/sphinx-notfound-page/pull/98>`__)

Version 0.5
-----------

:Date: July 23, 2020

* `@humitos <https://github.com/humitos>`__: Update Sphinx==3.1.2 (`#99 <https://github.com/readthedocs/sphinx-notfound-page/pull/99>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx-rtd-theme to 0.5.0 (`#98 <https://github.com/readthedocs/sphinx-notfound-page/pull/98>`__)
* `@jdillard <https://github.com/jdillard>`__: Add warning about local web server for #95 (`#97 <https://github.com/readthedocs/sphinx-notfound-page/pull/97>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx-autoapi to 1.4.0 (`#96 <https://github.com/readthedocs/sphinx-notfound-page/pull/96>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinxemoji to 0.1.6 (`#93 <https://github.com/readthedocs/sphinx-notfound-page/pull/93>`__)
* `@huonw <https://github.com/huonw>`__: Remind about `:orphan:` in 404.rst, to silence build warnings (`#91 <https://github.com/readthedocs/sphinx-notfound-page/pull/91>`__)
* `@humitos <https://github.com/humitos>`__: Implement `notfound_urls_prefix` to replace 3 deprecated configs (`#90 <https://github.com/readthedocs/sphinx-notfound-page/pull/90>`__)
* `@humitos <https://github.com/humitos>`__: :nosearch: metadata on 404 page (`#89 <https://github.com/readthedocs/sphinx-notfound-page/pull/89>`__)
* `@humitos <https://github.com/humitos>`__: Add more test environments (`#88 <https://github.com/readthedocs/sphinx-notfound-page/pull/88>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx-autoapi to 1.3.0 (`#86 <https://github.com/readthedocs/sphinx-notfound-page/pull/86>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinxemoji to 0.1.5 (`#85 <https://github.com/readthedocs/sphinx-notfound-page/pull/85>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinxemoji to 0.1.4 (`#83 <https://github.com/readthedocs/sphinx-notfound-page/pull/83>`__)
* `@Daltz333 <https://github.com/Daltz333>`__: Fix sphinx3 deprecation (`#82 <https://github.com/readthedocs/sphinx-notfound-page/pull/82>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx-autoapi to 1.2.1 (`#78 <https://github.com/readthedocs/sphinx-notfound-page/pull/78>`__)
* `@agnieszkawierzbowska <https://github.com/agnieszkawierzbowska>`__: Update how-it-works.rst (`#77 <https://github.com/readthedocs/sphinx-notfound-page/pull/77>`__)
* `@agnieszkawierzbowska <https://github.com/agnieszkawierzbowska>`__: Update configuration.rst (`#75 <https://github.com/readthedocs/sphinx-notfound-page/pull/75>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx-tabs to 1.1.13 (`#74 <https://github.com/readthedocs/sphinx-notfound-page/pull/74>`__)
* `@humitos <https://github.com/humitos>`__: Extend options for setup.py (`#73 <https://github.com/readthedocs/sphinx-notfound-page/pull/73>`__)
* `@humitos <https://github.com/humitos>`__: Test on sphinx 2.2.0 (`#72 <https://github.com/readthedocs/sphinx-notfound-page/pull/72>`__)
* `@humitos <https://github.com/humitos>`__: Use pytest.mark.environ to set environment variables (`#71 <https://github.com/readthedocs/sphinx-notfound-page/pull/71>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx-tabs to 1.1.12 (`#70 <https://github.com/readthedocs/sphinx-notfound-page/pull/70>`__)
* `@dojutsu-user <https://github.com/dojutsu-user>`__: Change `rtfd` to `readthedocs` everywhere (`#69 <https://github.com/readthedocs/sphinx-notfound-page/pull/69>`__)
* `@pyup-bot <https://github.com/pyup-bot>`__: Update sphinx-autoapi to 1.1.0 (`#67 <https://github.com/readthedocs/sphinx-notfound-page/pull/67>`__)
* `@humitos <https://github.com/humitos>`__: Automatic add :orphan: to avoid Sphinx WARNING (`#66 <https://github.com/readthedocs/sphinx-notfound-page/pull/66>`__)
* `@acozine <https://github.com/acozine>`__: Improves configuration page of documentation (`#45 <https://github.com/readthedocs/sphinx-notfound-page/pull/45>`__)

Version 0.4
-----------

:Date: June 11, 2019

* `@humitos <http://github.com/humitos>`__: Copy image into output dir when using .. image:: directive (`#46 <https://github.com/rtfd/sphinx-notfound-page/pull/46>`__)
* `@humitos <http://github.com/humitos>`__: Allow using image directive with non-local images (`#40 <https://github.com/rtfd/sphinx-notfound-page/pull/40>`__)
* `@humitos <http://github.com/humitos>`__: Pin Sphinx below 2.0 because it does not render properly (`#53 <https://github.com/rtfd/sphinx-notfound-page/pull/53>`__)
* `@pyup-bot <http://github.com/pyup-bot>`__: Update sphinxemoji to 0.1.1 (`#51 <https://github.com/rtfd/sphinx-notfound-page/pull/51>`__)
* `@humitos <http://github.com/humitos>`__: Run tox docs with -W (`#49 <https://github.com/rtfd/sphinx-notfound-page/pull/49>`__)
* `@humitos <http://github.com/humitos>`__: Use :orphan: to remove Sphinx warning (`#47 <https://github.com/rtfd/sphinx-notfound-page/pull/47>`__)
* `@humitos <http://github.com/humitos>`__: Copy image into output dir when using .. image:: directive (`#46 <https://github.com/rtfd/sphinx-notfound-page/pull/46>`__)
* `@acozine <http://github.com/acozine>`__: Improves configuration page of documentation (`#45 <https://github.com/rtfd/sphinx-notfound-page/pull/45>`__)
* `@humitos <http://github.com/humitos>`__: Specify extension metadata (`#44 <https://github.com/rtfd/sphinx-notfound-page/pull/44>`__)
* `@stsewd <http://github.com/stsewd>`__: Don't list sphinx as a requirement (`#43 <https://github.com/rtfd/sphinx-notfound-page/pull/43>`__)
* `@humitos <http://github.com/humitos>`__: Run tests on Sphinx 2.1.0 (`#37 <https://github.com/rtfd/sphinx-notfound-page/pull/37>`__)
* `@humitos <http://github.com/humitos>`__: Add useful resources in the index docs page (`#34 <https://github.com/rtfd/sphinx-notfound-page/pull/34>`__)
* `@humitos <http://github.com/humitos>`__: Generate proper Toctree URLs when _version and _language are set (`#31 <https://github.com/rtfd/sphinx-notfound-page/pull/31>`__)
* `@humitos <http://github.com/humitos>`__: Setup travis-ci (`#30 <https://github.com/rtfd/sphinx-notfound-page/pull/30>`__)
* `@humitos <http://github.com/humitos>`__: Resolve internal Sphinx javascript resources URLs (`#29 <https://github.com/rtfd/sphinx-notfound-page/pull/29>`__)
* `@humitos <http://github.com/humitos>`__: Generate valid links for toctree when using DirectoryHTMLBuilder (`#28 <https://github.com/rtfd/sphinx-notfound-page/pull/28>`__)
* `@humitos <http://github.com/humitos>`__: Docs for "How it works" (`#23 <https://github.com/rtfd/sphinx-notfound-page/pull/23>`__)
* `@humitos <http://github.com/humitos>`__: More tox test envs (`#22 <https://github.com/rtfd/sphinx-notfound-page/pull/22>`__)
* `@humitos <http://github.com/humitos>`__: Allow ..image:: directive on 404.rst (`#21 <https://github.com/rtfd/sphinx-notfound-page/pull/21>`__)
* `@humitos <http://github.com/humitos>`__: Tests for toctree links (`#19 <https://github.com/rtfd/sphinx-notfound-page/pull/19>`__)


Version 0.3
-----------

:Date: May 25, 2019

* Better documentation
* `#13 <https://github.com/rtfd/sphinx-notfound-page/pull/13>`_ Added ``notfound_no_urls_prefix`` configuration


Version 0.2.1
-------------

:Date: March 29, 2019

* Fix release version issue


Version 0.2
-----------

:Date: March 29, 2019

* `#6 <https://github.com/rtfd/sphinx-notfound-page/issues/6>`_ Sidebar links broken


Version 0.1
-----------

:Date: February 4, 2019

Initial release.
